import { Modal, message } from 'antd';
import { ComponentManager } from '../sgiFactory/ComponentManager';
const confirm = Modal.confirm; //使用 confirm() 可以快捷地弹出确认框
import React from 'react';
import ReactDOM from 'react-dom';
import { SgiModal } from '../sgiComp/SgiModal';
import { refModalFunction } from '../sgiComp/SgiCompComm';
import * as sgiCommon from './sgiCommon'

window.tool = {

    Global: {
        currentAP: "SD"
    },

    /**
      * 根据useCode，获取页面对象（UCV、容器、WV、控件）
      *
      * @param useCode
      * @return UseInfo
      */
    getCmp: function (useCode, objFct) {
        if (!useCode || !objFct) {
            return;
        }
        let uid = objFct.getUID();
        if (!uid) {
            return;
        }
        return ComponentManager.get(uid, useCode);
    },
    /**
     * 刷新WV中的数据
     *
     * @param {string}
     *            WV的useCode
     * @returns {boolean} 刷新是否成功 刷新成功：true 刷新失败：false
     */
    refreshWV: function (wvCode, objFct) {
        if (!wvCode || !objFct) {
            return false;
        }
        let uid = objFct.getUID();
        if (!uid) {
            return false;
        }
        let wv = ComponentManager.get(uid, wvCode);
        if (wv) {
            wv.refreshValues();
            return true;
        }
    },
    /**
    * 弹出信息对话框
    *
    * @param title
    *            对话框标题.
    * @param msg
    *            对话框内容.
    * @param callbackClose
    *            确认按钮的回调函数
    * @param state根据参数显示不同icon，
    *            ‘info’、‘success’、‘error’、‘warning’、‘confirm’
    * @param okText
    *            确认按钮文字,默认：确定
    */
    popMsgDialog: function (title, msg, callbackClose, state, okText) {
        var something = {
            title: title,
            content: msg,
            onOk: callbackClose,
            okText: okText
        };
        switch (state) {
            case "info":
            default:
                Modal.info(something);
                break;
            case "success":
                Modal.success(something);
                break;
            case "error":
                Modal.error(something);
                break;
            case "warning":
                Modal.warning(something);
                break;
            case "confirm":
                Modal.confirm(something);
                break;
        }
    },
    /**
       * 弹出信息确认对话框
       *
       * @param title
       *            对话框标题.
       * @param msg
       *            对话框内容.
       * @param callbackCancel
       *            取消按钮回调函数
       * @param callbackConfirm
       *            确认按钮回调函数
       * @param cancelText
       *            取消按钮文字，默认：取消
       * @param okText
       *            确认按钮文字，默认：确定
       */
    popConfirmDialog: function (title, msg, callbackCancel, callbackConfirm, cancelText, okText) {
        confirm({
            title: title,
            content: msg,
            onCancel: callbackCancel,
            onOk: callbackConfirm,
            cancelText: cancelText,
            okText: okText
        });
    },
    /**
       * 信息全局提示
       *
       * @param content
       *            全局提示的内容.
       * @param state
       *            提示的类型，success、error、info、warning、warn（警告的别名）、loading
       * @param onClose
       *            关闭时触发的回调函数
       * @param [duration]
       *            自动关闭的延时，单位秒.默认：3
       */
    popMessage: function (content, state, onClose, duration) {
        switch (state) {
            case "info":
            default:
                message.info(content, duration, onClose);
                break;
            case "success":
                message.success(content, duration, onClose);
                break;
            case "error":
                message.error(content, duration, onClose);
                break;
            case "warning":
                message.warning(content, duration, onClose);
                break;
            case "warn":
                message.warn(content, duration, onClose);
                break;
            case "loading":
                message.loading(content, duration, onClose);
                break;
        }
    },
    /**
       * 通用的弹出窗体，使用任何页面作为弹出窗，指定高度宽度
       *
       * @param {object}
       *            uid 页面id
       * @param {object}
       *            objFct 对象工厂
       * @param {Object}
       *            curtitle 指定标题
       */
    popUI: function (uid, objFct, curtitle) {
        var mainComp = this.getCmp(objFct.getUID(), objFct);
        mainComp.addModal(
            <SgiModal ref={refModalFunction} uid={uid} objFct={objFct} curtitle={curtitle} visible={true} />);

        mainComp.setState({ loading: false });
    },
    /**
     * 关闭弹出窗体
     * @param  {[type]} objFct [对象工厂]
     * @return {[type]}        [description]
     */
    popClose: function (objFct) {
        var mainComp = this.getCmp(objFct.getUID(), objFct);
        var sgiModal = mainComp.getModal();
        if (!sgiModal) {
            return;
        }
        sgiModal.onCancel();
        mainComp.removeModal();
        mainComp.setState({ loading: false });
    },

    /***************************************************************************
           * 以上弹出窗部分
           **************************************************************************/
    /***************************************************************************
           * 以下树控件方法部分
           **************************************************************************/
    /**
     * 刷新树
     * @param  {[string]} treeId   [树控件的组件标识]
     * @param  {[Array]} treeData [树的数据]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[type]}          [description]
     */
    refreshTree: function (treeId, treeData, objFct) {
        var tree = this.getCmp(treeId, objFct);
        if (!tree) {
            return;
        }
        tree.refreshTree(treeData);
    },
    /**
     * 获取已选中/勾选节点（单选）
     * @param  {[string]} treeId   [树控件的组件标识]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[Array]}        [已选中/勾选的节点数据数组]
     */
    getSelection: function (treeId, objFct) {
        var tree = this.getCmp(treeId, objFct);
        if (!tree) {
            return;
        }
        return tree.getSelection();
    },
    /**
     * 展开树的某个节点（缺点：只在树单击中好用）
     * @param  {[string]} treeId   [树控件的组件标识]
     * @param  {[object]} treeNode [树节点结构]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[type]}          [description]
     */
    expand: function (treeId, treeNode, objFct) {
        var tree = this.getCmp(treeId, objFct);
        if (!tree) {
            return;
        }
        tree.expand(treeNode);
    },
    /**
     * 删除树的选中数据
     * @param  {[string]} treeId   [树控件的组件标识]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[Array]}        [删除后的treeData]
     */
    delTreeSel: function (treeId, objFct) {
        var tree = this.getCmp(treeId, objFct);
        if (!tree) {
            return;
        }
        return tree.delTreeSel();
    },
    /**
     * 删除树的一个节点
     * @param  {[string]} treeId   [树控件的组件标识]
     * @param  {[object]} node   [节点数据信息]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[type]}        [description]
     */
    delTreeNode: function (treeId, node, objFct) {
        var tree = this.getCmp(treeId, objFct);
        if (!tree) {
            return;
        }
        return tree.delTreeNode(node);
    },

    /***************************************************************************
           * 以上树控件方法部分
           **************************************************************************/
    /***************************************************************************
           * 以下表格控件方法部分
           **************************************************************************/
    /**
     * 刷新表格控件
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[Array]} tableData [表格数据对象数组]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[type]}           [description]
     */
    refreshTable: function (tableId, tableData, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        table.refreshTable(tableData);
    },
    /**
     * 获取表格已选中/已勾选数据
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[obj/list]} [已选中对象/已勾选行对象数组]
     */
    getTbSels: function (tableId, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        return table.getTbSels();
    },
    /**
     * 获取表格所有数据
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[Array]}         [表格数据对象数组]
     */
    getTbData: function (tableId, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        return table.getTbData();
    },
    /**
     * 向表格中添加新数据
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[object]} newData [要添加的数据对象]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[type]}         [description]
     */
    addTbNewData: function (tableId, newData, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        table.addTbNewData(newData);
    },
    /**
     * 删除表格选中数据
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[Array]}         [删除后的表格数据对象数组]
     */
    delTableSel: function (tableId, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        return table.delTableSel();
    },
    /**
     * 删除表格指定行数据
     * @param  {[String]} tableId   [表格控件的组件标识]
     * @param  {[object]} delData [要删除的单行数据]
     * @param  {[object]} objFct   [对象工厂]
     * @return {[Array]}         [删除后的表格数据对象数组]
     */
    delTableObj: function (tableId, delData, objFct) {
        var table = this.getCmp(tableId, objFct);
        if (!table) {
            return;
        }
        return table.delTableObj(delData);
    },
    /***************************************************************************
          * 以上表格控件方法部分
          **************************************************************************/
    /***************************************************************************
           * 以下页面处理部分
           **************************************************************************/
    /**
     * 切换选项卡/层叠面板/折叠面板到指定itemId的页面
     * @param  {[string]} ctnId  [容器id]
     * @param  {[string]} itemId [子面板id]
     * @param  {[object]} objFct [对象工厂]
     * @return {[type]}        [description]
     */
    setActiveItem: function (ctnId, itemId, objFct) {
        var container = this.getCmp(ctnId, objFct);
        if (!container) {
            return;
        }
        container.setActiveItem(itemId);
    },
    /**
     * 获取当前激活面板的组件标识
     * @param  {[string]} ctnId  [容器id]
     * @param  {[object]} objFct [对象工厂]
     * @return {[String]}        [当前激活面板的组件标识]
     */
    getActiveItem: function (ctnId, objFct) {
        var container = this.getCmp(ctnId, objFct);
        if (!container) {
            return;
        }
        return container.getActiveItem(ctnId);
    },
    /**
     * 获取对象值
     * @param  {[Object]} obj  [对象]
     * @param  {[string]} code [属性编码]
     * @return {[Object]}      [属性值]
     */
    getVal: function (obj, code) {
        if (!obj || !code) {
            return;
        }
        return obj[code];
    },
    /**
     * 设置对象值
     * @param  {[Object]} obj  [对象]
     * @param  {[string]} code [属性编码]
     * @param  {[Object]} value [属性值]
     * @return {[type]}       [description]
     */
    setVal: function (obj, code, value) {
        if (!obj || !code) {
            return;
        }
        obj[code] = value;
    },

    /***************************************************************************
           * 以上页面处理部分
           **************************************************************************/
    /***************************************************************************
           * 以下控件部分
           **************************************************************************/
    /**
       * 根据控件的UseCode，设置控件是否禁用
       *
       * @param {String}
       *            ctlId 控件的UseCode
       * @param {boolean}
       *            enabled 是否禁用
       */
    setDisabled: function (ctlId, enabled, objFct) {
        var ctl = this.getCmp(ctlId, objFct);
        if (!ctl) {
            return;
        }
        ctl.setDisabled(enabled);
    },
    /**
       * 根据控件的UseCode，设置控件是否隐藏
       *
       * @param {String}
       *            ctlId 控件的UseCode
       * @param {boolean}
       *            visible 是否隐藏
       */
    setHidden: function (ctlId, visible, objFct) {
        var ctl = this.getCmp(ctlId, objFct);
        if (!ctl) {
            return;
        }
        ctl.setHidden(visible);
    },
    /**
     * 设置控件显示值
     * @param  {[string]} ctlId  [控件的UseCode]
     * @param  {[object]} value  [显示值]
     * @param  {[Object]} objFct [对象工厂]
     * @return {[type]}        [description]
     */
    setValue: function (ctlId, value, objFct) {
        var ctl = this.getCmp(ctlId, objFct);
        if (!ctl) {
            return;
        }
        ctl.setValue(value);
    },

    /**
    
        /****************************************************************************************** */
    /****************************************************************************************** */
    /*************************下面这些没实现，没测试********************************************* */
    /****************************************************************************************** */
    /****************************************************************************************** */
    /****************************************************************************************** */


    /***************************************************************************
           * 以上弹出窗部分
           **************************************************************************/
    /***************************************************************************
           * 以下页面处理部分
           **************************************************************************/
    /**
       * 克隆对象
     * @param obj 对象
       */
    clone: function (obj) {
        // if (!obj) {
        // 	return obj;
        // }
        // if (obj instanceof Array){
        // 	var cloneArr = [];
        // 	Ext.each(obj,function(record){
        // 		if (record.isModel){
        // 			cloneArr.push(Ext.clone(record.data))
        // 		} else {
        // 			cloneArr.push(Ext.clone(record))
        // 		}
        // 	});
        // 	return cloneArr;
        // } else {
        // 	if (obj.isModel){
        // 		return Ext.clone(obj.data);
        // 	} else {
        // 		return Ext.clone(obj);
        // 	}
        // }
    },
    /**
       * 根据页面对象，获取UCV
       *
       * @param UseInfo
       * @return ucv
       */
    getUCV: function (UseInfo) {
        // if (Ext.isEmpty(UseInfo)) {
        // 	return null;
        // }
        // var ownerCt = this.getOwnerCt(UseInfo);
        // var ucv;
        // var temp;
        // while (ownerCt) {
        // 	temp = ownerCt;
        // 	ownerCt = this.getOwnerCt(ownerCt);
        // }
        // ucv = temp;
        // return ucv;
    },
    /**
       * 根据控件编码属性获取控件id
       *
       * @param {type}
       *            ctnId
       * @param {type}
       *            ctlName
       * @returns {undefined}
       */
    getCtlFromCtn: function (ctnId, ctlName) {
        // var ctn = this.getCmp(ctnId);
        // if (!ctn) {
        // 	return null;
        // }
        // var ctl = ctn.form.findField(ctlName);
        // if (!ctl) {
        // 	return null;
        // }
        // return ctl;
    },

    /**
       * 重置WV中的数据
       *
       * @param {string}
       *            useCode WV的useCode
       * @return {boolean} 重置是否成功
       */
    resetWV: function (wvCode) {
        // if (Ext.isEmpty(wvCode)) {
        //     return false;
        // }
        // var wv = this.getCmp(wvCode);
        // if (!this.isWVByCp(wv)) {
        //     return false;
        // }
        // wv.reset();
        // return true;
    },
    /***************************************************************************
   * 以上页面处理部分
   **************************************************************************/
    /***************************************************************************
   * 以下控件部分
   **************************************************************************/
    /**
       * 根据控件所在WV的UseCode和控件的UseCode，设置控件是否可用
       *
       * @param {String}
       *            wvCode WV的UseCode
       * @param {String}
       *            ctlCode 控件的UseCode
       * @param {boolean}
       *            enabled 是否可用
       */
    setCtlEnabled: function (wvCode, ctlCode, enabled) {
        // var wv = this.getCmp(wvCode);
        // if (!wv) {
        //     return;
        // }
        // var ctl = wv.form.findField(ctlCode);
        // if (!ctl) {
        //     return;
        // }
        // ctl.setDisabled(enabled);
    },

    /**
       * 根据控件所在WV的UseCode和控件的UseCode，设置控件是否可见
       *
       * @param {String}
       *            wvCode WV的UseCode
       * @param {String}
       *            ctlCode 控件的UseCode
       * @param {boolean}
       *            visible 是否可见
       */
    setCtlVisible: function (wvCode, ctlCode, visible) {
        // var wvpanel = this.getCmp(wvCode);
        // if (!wvpanel) {
        //     return;
        // }
        // var ctl = wvpanel.form.findField(ctlCode);
        // if (ctl && ctl._dmJson.desId === Ep.GUID.POPUI) {
        //     ctl.ownerCt.setVisible(visible);
        // }
    },

    /**
       * 根据控件所在WV的UseCode和控件的UseCode，设置控件是否只读
       *
       * @param {String}
       *            wvCode WV的UseCode
       * @param {String}
       *            ctlCode 控件的UseCode
       * @param {boolean}
       *            readOnly 是否可见
       */
    setCtlReadOnly: function (wvCode, ctlCode, readOnly) {
        // var wv = this.getCmp(wvCode);
        // if (!wv) {
        //     return;
        // }
        // var ctl = wv.form.findField(ctlCode);
        // if (!ctl) {
        //     return;
        // }
        // ctl.setReadOnly(readOnly);
    },
    /**
       * 根据控件所在WV的UseCode和控件的UseCode，设置控件是否只读
       *
       * @param {String}
       *            wvCode WV的UseCode
       * @param {boolean}
       *            readOnly 是否可见
       */
    setReadOnly: function (ctlId, readOnly) {
        // var wv = this.getCmp(ctlId);
        // if (!wv) {
        //     return;
        // }
        // wv.setReadOnly(readOnly);
    },
    /**
       * 选中首行
       */
    selFirst: function (cid) {
        // var table = this.getCmp(cid);
        // if (Ext.isEmpty(table)) {
        //     console.log("can't find table/tree " + cid);
        //     return;
        // }
        // var record = table.getSelectionModel().store.getAt(0);
        // if (record) {
        //     table.getSelectionModel().select(0, true, false);
        //     table.fireEvent("itemclick", table.getView(), record);
        // }
    },
    /**
       * 刷新表格中数据
       *
       * @param {string}
       *            tableId 表格的useCode
       * @returns {undefined}
       */
    refreshTable: function (tableId) {
        // var table = this.getCmp(tableId);
        // if (Ext.isEmpty(table)) {
        //     console.log("can't find table " + tableId);
        //     return;
        // }
        // table.reLoadData();
        // // table.getSelectionModel().select(0, true, false);
    },
    /**
       * 获取表格选中数据
       *
       * @param {string}
       *            tableId 表格的useCode
       * @returns {undefined}
       */
    getTreeChks: function (tableId) {
        // var table = this.getCmp(tableId);
        // if (Ext.isEmpty(table)) {
        //     // console.log("can't find table " + tableId);
        //     return [];
        // }
        // // 不用自己封装的map获取选中记录，改用自带方法
        // return table.getChecked();
    },
    /**
       * 获取表格选中数据 树表通用
       *
       * @param {string}
       *            tableId 表格的useCode
       * @returns {undefined}
       */
    getTbSels: function (tableId) {
        // var table = this.getCmp(tableId);
        // if (Ext.isEmpty(table)) {
        //     // console.log("can't find table " + tableId);
        //     return [];
        // }
        // // 不用自己封装的map获取选中记录，改用自带方法
        // return table.getSelectionModel().getSelection();
    },
    /**
       * 向表格中添加新数据
       *
       * @param {string}
       *            tableId 表格的useCode
       * @returns {undefined}
       */
    addTabNewData: function (tableId, newData) {
        // var store = this.getCmp(tableId).getStore();
        // if (!store) {
        //     return;
        // }
        // store.add(newData);
    },
    /**
       * 删除表格 选中数据
       */
    delTableSel: function (wvid) {
        // var sm = this.getCmp(wvid).getSelectionModel();
        // if (!sm) {
        //     return;
        // }
        // var store = this.getCmp(wvid).getStore();
        // if (!store) {
        //     return;
        // }
        // var rts = sm.getSelection();
        // store.remove(rts);
        // return rts;
    },
    /**
       * 删除表格 某一数据
       */
    delTableObj: function (wvid, record) {
        // if (!record) {
        //     return;
        // }
        // var store = this.getCmp(wvid).getStore();
        // if (!store) {
        //     return;
        // }
        // store.remove(record);
    },
    /**
       * 定位到树的所选节点
       *
       * @param {type}
       *            treeCode
       * @param {type}
       *            node
       * @returns {undefined}
       */
    toTreeSelection: function (treeCode, node) {
        // var tree = this.getCmp(treeCode);
        // if (Ext.isEmpty(tree)) {
        //     // console.log("can't find tree " + treeCode);
        //     return;
        // }
        // tree.getSelectionModel().select(node);
        // tree.fireEvent("itemclick", tree.getView(), node);
    },
    /**
       * 展开树上节点
       *
       * @param {type}
       *            treeCode
       * @param {boolean}
       *            deep
       * @returns {undefined}
       */
    setNodeExpand: function (node, deep) {
        // if (Ext.isEmpty(node)) {
        //     // console.log("can't find node ");
        //     return;
        // }
        // if (deep) {
        //     node.expand(true);
        // } else {
        //     node.expand();
        // }
    },
    /**
       * 嵌入ui面板
       */
    panelAddUcv: function (wvid, ucvid, flag) {
        // var panel = this.getCmp(wvid);
        // if (!panel) {
        //     return;
        // }
        //
        // // 设置添加列表
        // if (!panel.addUCVList) {
        //     panel.addUCVList = {};
        // }
        //
        // // 是否清空重新添加
        // if (flag) {
        //     panel.removeAll(true);
        //     panel.addUCVList = {};
        // } else {
        //     // 判断是否已经添加过了 添加过了 返回不再添加
        //     if (panel.addUCVList[ucvid]) {
        //         return;
        //     }
        // }
        //
        // var uiJson = Ep.PrmFactory.getPrmJson(ucvid);
        // if (!uiJson) {
        //     return;
        // }
        // var ucv = Ep.UBMainMaker.main(null, uiJson, this.objFct, null, this.ws);
        // panel.add(ucv.items.items);
        // // 设置添加标示
        // panel.addUCVList[ucvid] = true;
    }

}
Object.assign(tool, sgiCommon);
export { tool };
